<?php
/**
 * Theme functions and definitions
 */


/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1170;
}

/**
 * 	fincorbus Theme Setup
 */

if ( ! function_exists( 'fincorbus_setup' ) ) :
function fincorbus_setup() {

	//	Make theme available for translation.
	load_theme_textdomain( 'fincorbus', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	//	Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	//	Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 565, true );
	
	// Blog Thumbnails Size
	add_image_size( 'fincorbus-blog-default', 770, 420, true );
	add_image_size( 'fincorbus_700x540', 700, 540, true );
	add_image_size( 'fincorbus_570x400', 570, 400, true );
	add_image_size( 'fincorbus_370x270', 370, 250, true );
	add_image_size( 'fincorbus_300x320', 300, 320, true );
	add_image_size( 'fincorbus_270x180', 270, 180, true );
	add_image_size( 'fincorbus_281x156', 281, 156, true );
	add_image_size( 'fincorbus_1170x620', 1170, 620, true );
	add_image_size( 'fincorbus_69x69', 69, 69, true );
	add_image_size( 'fincorbus_574x9999', 574, 9999, false );
	add_image_size( 'fincorbus_490x9999', 490, 9999, false );
	add_image_size( 'fincorbus_270x9999', 270, 9999, false );
	add_image_size( 'fincorbus_370x9999', 370, 9999, false );
	add_image_size( 'fincorbus_1170x9999', 1170, 9999, false );
	
	//	Portfolio Thumbnails Size
	add_image_size( 'fincorbus_585x400', 585, 400, true );
	add_image_size( 'fincorbus_570x590', 570, 590, true );
	add_image_size( 'fincorbus_570x570', 570, 570, true );
	add_image_size( 'fincorbus_500x795', 500, 795, true );
	add_image_size( 'fincorbus_470x280', 470, 280, true );
	add_image_size( 'fincorbus_370x390', 370, 390, true );
	add_image_size( 'fincorbus_270x180', 270, 180, true );
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'fincorbus' )
	) );

	//	Switch default core markup for search form, comment form, and comments
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	//	Enable support for Post Formats.
	function fincorbus_post_type( $current_screen ) {
		if ( 'post' == $current_screen->post_type && 'post' == $current_screen->base ) {
			add_theme_support( 'post-formats', array('image', 'gallery', 'link', 'quote', 'audio', 'video'));
		}
	}
	add_action( 'current_screen', 'fincorbus_post_type' );

	add_theme_support( 'post-formats', array( 'audio', 'gallery', 'video') );
	add_post_type_support( 'portfolio', 'post-formats' );
	
	//This theme support custom header
    add_theme_support( 'custom-header' );

    //This theme support custom backgrounds
    add_theme_support( 'custom-backgrounds' );

}
endif; // fincorbus_setup
add_action( 'after_setup_theme', 'fincorbus_setup' );


/**
 * Include files
 */

//	Theme Functions
require_once( get_template_directory() . '/inc/theme_functions.php' );

//	Theme style, jQuery
require_once( get_template_directory() . '/inc/enqueue.php' );

//	Plugin Recommendations
require_once( get_template_directory() . '/inc/plugins/install-plugin.php' );

//	Widgets
require_once( get_template_directory() . '/inc/widgets/widgets.php' );

//	Initialize the mega menu framework
require_once( get_template_directory() . '/inc/megamenu/wp_bootstrap_navwalker.php' );
require_once( get_template_directory() . '/inc/megamenu/wp_bootstrap_mobile_navwalker.php' );
require_once( get_template_directory() . '/inc/megamenu/megamenu_functions.php' );

//	Redux Theme Options
if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
	require_once( get_template_directory() . '/inc/theme-options/options.php' );
}

//	Breadcrumbs
require_once( get_template_directory() . '/inc/breadcrumbs.php' );

//	WooCommerce
if(class_exists('Woocommerce')) {
	require_once( get_template_directory() .'/inc/woo_functions.php' );
}