<?php

/* Load frontend scripts and styles */
add_action( 'wp_enqueue_scripts', 'fincorbus_load_scripts' );

/**
 * Load scripts and styles on frontend
 */

function fincorbus_load_scripts() {
	fincorbus_load_css();
	fincorbus_load_js();
}

/**
 * Load frontend css files
 */

function fincorbus_load_css() {
	
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css');
	wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css');
	wp_enqueue_style('fincorbus-evathemeicons', get_template_directory_uri() . '/assets/css/Evatheme-Icon-Fonts.css');
	wp_enqueue_style('swipebox', get_template_directory_uri() . '/assets/css/plugins/swipebox.min.css', array(), '1.4.4');
	wp_enqueue_style('fincorbus-owlcarousel', get_template_directory_uri() . '/assets/css/custom-owlcarousel.css');
	
	//	WooCommerce custom styles
	if( class_exists('Woocommerce') ) {
		wp_enqueue_style('fincorbus-woo', get_template_directory_uri() . '/assets/css/custom-woo.css');
	}
	wp_enqueue_style('fincorbus-theme', get_template_directory_uri() . '/assets/css/theme-style.css');
	wp_add_inline_style('fincorbus-theme', fincorbus_generate_dynamic_css() );
	wp_enqueue_style('fincorbus-responsive', get_template_directory_uri() . '/assets/css/responsive.css');
	wp_enqueue_style('fincorbus-default', get_stylesheet_uri());
	
	if( !class_exists( 'ReduxFrameworkPlugin' ) ) {
		wp_enqueue_style('fincorbus-google-fonts', fincorbus_google_fonts_url(), array(), '1.0.0' );
	}

}


/**
 * Load frontend js files
 */

function fincorbus_load_js() {

	global $post;
	
	wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array(), '3.3.4', true);
	wp_enqueue_script('swipebox', get_template_directory_uri() . '/assets/js/plugins/jquery.swipebox.min.js', 'jquery', '1.4.4', true);
	wp_enqueue_script('mousewheel', get_template_directory_uri() . '/assets/js/jquery.mousewheel.js', array( 'jquery' ), '3.1.9', true);
	wp_enqueue_script('owlcarousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array(), false, true);
	wp_enqueue_script('fincorbus-isotope', get_template_directory_uri() . '/assets/js/custom-isotope.js', array('jquery'), false, true);
	
	$fincorbus_func_fixed_sidebar = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('func_fixed_sidebar') : '0';
	$fincorbus_post_single_style = is_singular('post') ? get_post_meta( $post->ID, 'fincorbus_post_single_style', true ) : '';
	if( $fincorbus_func_fixed_sidebar != '0' && $fincorbus_post_single_style != 'fullscreen' ) {
		wp_enqueue_script('fincorbus-stickysidebar', get_template_directory_uri() . '/assets/js/custom-stickysidebar.js', array(), false, true);
	}
	
	//	Headroom function
	$fincorbus_fixed_header = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('fixed_header') : '1';
	if( get_page_template_slug() != "page-comingsoon.php" && $fincorbus_fixed_header != 0 ) {
		wp_enqueue_script('headroom', get_template_directory_uri() . '/assets/js/headroom.min.js', array(), '0.9.3', true);
	}
	
	//	WooCommerce custom jQuery
	if( class_exists('Woocommerce') ) {
		if( is_singular('product') ){
			wp_enqueue_script('slick', get_template_directory_uri() . '/assets/js/plugins/slick.min.js', array( 'jquery' ), '1.6.0', true);
		}
		wp_enqueue_script('fincorbus-woo', get_template_directory_uri() . '/assets/js/custom-woo.js', array( 'jquery' ), '', true);
	}
	wp_enqueue_script('fincorbus-script', get_template_directory_uri() . '/assets/js/theme-script.js', array( 'jquery' ), '', true);
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	//	Coming Soon Page
	if( get_page_template_slug() == "page-comingsoon.php" ) {
		
		wp_enqueue_script('fincorbus-downCount', get_template_directory_uri() . '/assets/js/jquery.downCount.js', array('jquery'), false, true);
		
		$fincorbus_comings_soon_years 	= get_post_meta( $post->ID, 'fincorbus_comings_soon_years', true );
		$fincorbus_comings_soon_months 	= get_post_meta( $post->ID, 'fincorbus_comings_soon_months', true );
		$fincorbus_comings_soon_days 	= get_post_meta( $post->ID, 'fincorbus_comings_soon_days', true );
		
		wp_add_inline_script( 'fincorbus-downCount', '
			
			jQuery(document).ready(function() {
				jQuery(".countdown").downCount({
					date: "'. esc_html( $fincorbus_comings_soon_months ) .'/'. esc_html( $fincorbus_comings_soon_days ) .'/'. esc_html( $fincorbus_comings_soon_years ) .' 12:00:00"
				});
			});
		
		' );
		
	}
}


/* Custom js */
function fincorbus_custom_js() {
	
	$fincorbus_custom_js = fincorbus_options('custom-js');
	
	if( class_exists( 'ReduxFrameworkPlugin' ) && !empty( $fincorbus_custom_js ) ) {
		echo fincorbus_options('custom-js');
	}
}
add_action('wp_footer', 'fincorbus_custom_js', 100);


/* Load backend scripts and styles */
add_action( 'admin_enqueue_scripts', 'fincorbus_load_admin_scripts' );

/**
 * Load scripts and styles on backend
 */

function fincorbus_load_admin_scripts() {
	fincorbus_load_admin_css();
	fincorbus_load_admin_js();
}

/**
 * Load backend css files
 */

function fincorbus_load_admin_css() {

	wp_enqueue_style('fincorbus-admin', get_template_directory_uri() . '/inc/assets/css/cstheme-admin.css');
	wp_enqueue_style('fincorbus-redux', get_template_directory_uri() . '/inc/assets/css/evatheme-redux-options.css');
	wp_enqueue_style('fincorbus-admin-google-fonts', fincorbus_admin_google_fonts_url(), array(), '1.0.0' );

}


/**
 * Load backend js files
 */

function fincorbus_load_admin_js() {

	wp_enqueue_script('fincorbus-admin', get_template_directory_uri() . '/inc/assets/js/cstheme-admin.js', array( 'jquery' ), '', true);
}


/**
 * Register Google Fonts url
 */

function fincorbus_google_fonts_url(){
	
	$google_font_url = add_query_arg( 'family', urlencode( 'Cabin:400,600,700&subset=latin,latin-ext' ), "//fonts.googleapis.com/css" );
	add_editor_style( $google_font_url );
	
    return $google_font_url;
}


/**
 * Admin Styles
 */

function fincorbus_admin_google_fonts_url(){
	
	$admin_google_font_url = add_query_arg( 'family', urlencode( 'Lato:300,400,700,900&subset=latin,latin-ext' ), "//fonts.googleapis.com/css" );
    add_editor_style( $admin_google_font_url );
	
	return $admin_google_font_url;
}