<?php
/**
 * Custom functions and definitions
 */


//	Theme Options
function fincorbus_options($index1, $index2 = false) {
    $options = get_option('fincorbus_option');
    if ($index2) {
        $output = isset($options[$index1][$index2]) ? $options[$index1][$index2] : false;
        return $output;
    }
    $output = isset($options[$index1]) ? $options[$index1] : false;
    return $output;
}


//	Add specific CSS class by filter
add_filter( 'body_class', 'fincorbus_body_class' );
function fincorbus_body_class( $classes ) {
	
	global $post;
	
	$fincorbus_postId = ( isset( $post->ID ) ? get_the_ID() : NULL );
	
	//	If Site Boxed
	if ( isset( $fincorbus_postId ) && get_post_meta( $fincorbus_postId, 'fincorbus_page_layout', true ) ) {
		$fincorbus_options_theme_layout = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('theme_layout') : 'full-width';
		$fincorbus_theme_layout = ( get_post_meta( $fincorbus_postId, 'fincorbus_page_layout', true ) ? get_post_meta( $fincorbus_postId, 'fincorbus_page_layout', true ) : $fincorbus_options_theme_layout );
	} else {
		$fincorbus_theme_layout = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('theme_layout') : 'full-width';
	}
	if ($fincorbus_theme_layout == 'boxed') {
		$classes[] = 'boxed';
	} else {
		$classes[] = 'full-width';
	}
	
	//	Header Layout
	$fincorbus_header_style = 'header-top';
	$classes[] = $fincorbus_header_style;
	
	//	Header has BG
	$fincorbus_header_bg_style = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('header_bg_style') : 'bgcolor';
	$fincorbus_header_page_bg_style = get_post_meta( $fincorbus_postId, 'fincorbus_header_page_bg_style', true );
	$fincorbus_header_bg_style = !empty( $fincorbus_header_page_bg_style ) ? $fincorbus_header_page_bg_style : $fincorbus_header_bg_style;
	if ( is_search() ) {
		$fincorbus_header_bg_style = 'bgcolor';
	}
	$classes[] = 'header_' . $fincorbus_header_bg_style;
	
	//	Header has BG with Opacity
	$fincorbus_header_bgcolor_opacity = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('header_bgcolor_opacity') : '95';
	if ( isset( $fincorbus_header_bg_style ) && $fincorbus_header_bgcolor_opacity != '99' ) {
		$classes[] = 'header_opacity';
	}
	
	//	Page Title show/hide
	$fincorbus_options_pagetitle = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('pagetitle') : 'show';
	$fincorbus_post_single_style = get_post_meta( $fincorbus_postId, 'fincorbus_post_single_style', true );
	$fincorbus_pagetitle = ( get_post_meta( $fincorbus_postId, 'fincorbus_pagetitle', true ) ? get_post_meta( $fincorbus_postId, 'fincorbus_pagetitle', true ) : $fincorbus_options_pagetitle );
	if ( is_home() || is_category() || is_tag() || is_search() || is_day() || is_month() || is_year() ) {
		$fincorbus_pagetitle = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('blog_pagetitle') : 'hide';
	} else if ( is_singular('post') && $fincorbus_post_single_style != 'fullscreen' ) {
		$fincorbus_pagetitle = 'hide';
	} else if ( is_singular('portfolio') ) {
		$fincorbus_pagetitle = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('portfolio_single_pagetitle') : 'show';
	} else if( class_exists('WooCommerce') && ( is_product_category() || is_product_tag() || is_cart() || is_checkout() || is_account_page() ) ) {
		$fincorbus_shop_pagetitle = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('shop_pagetitle') : 'show';
		$fincorbus_pagetitle = $fincorbus_shop_pagetitle;
	} else if( class_exists('WooCommerce') && ( is_shop() || is_singular('product') ) ) {
		$fincorbus_pagetitle = 'hide';
	}
	
	$classes[] = 'pagetitle_' . $fincorbus_pagetitle;
	
	//	Page Title show/hide
	$fincorbus_options_breadcrumbs = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('breadcrumbs') : 'show';
	$fincorbus_breadcrumbs = ( get_post_meta( $fincorbus_postId, 'fincorbus_breadcrumbs', true ) ? get_post_meta( $fincorbus_postId, 'fincorbus_breadcrumbs', true ) : $fincorbus_options_breadcrumbs );
	$classes[] = 'breadcrumbs_' . $fincorbus_breadcrumbs;
	
	//	Footer Fixed
	if( class_exists( 'ReduxFrameworkPlugin' ) && fincorbus_options('footer_fixed') != '0' ) {
		$classes[] = 'footer_fixed';
	}
	
	if ( class_exists( 'WooCommerce' ) ) {
		if( class_exists( 'ReduxFrameworkPlugin' ) && fincorbus_options('products_no_padding') != 0 ) {
			$classes[] = 'woo_no_paddings';
		}
	}
	
	return $classes;
}


//	if WooCommerce Plugin Active
function fincorbus_woo_enabled() {
    if ( class_exists( 'WooCommerce' ) )
        return true;
    return false;
}


/**
 * Insert social metadata into the header
 */
if ( ! function_exists( 'fincorbus_social_meta' ) ) {
	function fincorbus_social_meta() {

		global $post;

		if ( is_singular() ) {

	        echo '<meta property="og:title" content="' . get_the_title() . '"/>';
	        echo '<meta property="og:type" content="article"/>';
	        echo '<meta property="og:url" content="' . get_permalink() . '"/>';
	        echo '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '"/>';

			if ( has_post_thumbnail( $post->ID ) ) {
				$fincorbus_thumb = get_post_thumbnail_id();
				$fincorbus_img_url = wp_get_attachment_image_src( $fincorbus_thumb, 'large' );
				$fincorbus_img_url = $fincorbus_img_url[0];
			} else {
				$fincorbus_img_url = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('header-logo','url') : get_template_directory_uri() . '/assets/images/logo.png';
			}

			echo '<meta itemprop="image" content="' . $fincorbus_img_url . '"> ';
			echo '<meta name="twitter:image:src" content="' . $fincorbus_img_url . '">';
			echo '<meta property="og:image" content="' . $fincorbus_img_url . '" />';

		}
	}
}


//	Theme Logo
if ( ! function_exists( 'fincorbus_logo' ) ) { 
	function fincorbus_logo() {
		
		if ( ! class_exists( 'ReduxFrameworkPlugin' ) ) {
			$fincorbus_logo_src 		= get_template_directory_uri() . '/assets/images/logo.png';
			$fincorbus_logo_retina_src 	= '';
		} else {
			$fincorbus_header_logo_url 			= fincorbus_options('header-logo','url');
			$fincorbus_header_logo_retina_url 	= fincorbus_options('header-logo-retina','url');
			$fincorbus_header_logo_width 		= fincorbus_options('header-logo-width','url');
			
			$fincorbus_logo_src 		= !empty( $fincorbus_header_logo_url ) ? fincorbus_options('header-logo','url') : '';
			$fincorbus_logo_retina_src 	= !empty( $fincorbus_header_logo_retina_url ) ? fincorbus_options('header-logo-retina','url') : '';
			$fincorbus_logo_width 		= !empty( $fincorbus_header_logo_width ) ? fincorbus_options('header-logo-width') : '';
		}
		
		echo '<div class="cstheme-logo">';
			if ( $fincorbus_logo_src != '' || $fincorbus_logo_retina_src != '' ) {
				echo '<a class="logo" href="' . esc_url( home_url( '/' ) ) . '">';
					if( $fincorbus_logo_retina_src != '' ) {
						echo '<img class="logo-img retina" src="' . esc_url( $fincorbus_logo_retina_src ) . '" style="width:' . esc_attr( $fincorbus_logo_width ) . 'px" alt="' . get_bloginfo( 'name' ) . '" />';
					} else {
						echo '<img class="logo-img" src="' . esc_url( $fincorbus_logo_src ) . '" alt="' . get_bloginfo( 'name' ) . '" />';
					}
				echo '</a>';
			} else {
				echo '<h1 class="site-name">';
					echo '<a class="logo" href="'. esc_url( home_url( '/' ) ) .'">';
						bloginfo('name');
					echo '</a>';
				echo '</h1>';
			}
		echo '</div>';
	}
}


//	Theme Favicon
function fincorbus_favicon() {
	
	if ( !function_exists( 'has_site_icon' ) || !has_site_icon() ) {
		if(	class_exists('ReduxFrameworkPlugin') && fincorbus_options('favicon', 'url') ) {
			echo '<link rel="shortcut icon" href="' . esc_url( fincorbus_options('favicon', 'url') ) . '"/>';
		} else {
			echo '<link rel="shortcut icon" href="' . get_template_directory_uri() . '/assets/images/favicon.png" />';
		}
		
		if(class_exists('ReduxFrameworkPlugin') && fincorbus_options('favicon-retina', 'url') ) {
			echo '<link rel="apple-touch-icon" href="' . esc_url( fincorbus_options('favicon-retina', 'url') ) . '">';
		}
		if( class_exists('ReduxFrameworkPlugin') && fincorbus_options('apple_icons_57x57', 'url') ) {
			echo '<link rel="apple-touch-icon" sizes="57x57" href="' . esc_url( fincorbus_options('apple_icons_57x57', 'url') ) . '">';
		}
		if( class_exists('ReduxFrameworkPlugin') && fincorbus_options('apple_icons_72x72', 'url') ) {
			echo '<link rel="apple-touch-icon" sizes="72x72" href="' . esc_url( fincorbus_options('apple_icons_72x72', 'url') ) . '">';
		}
		if( class_exists('ReduxFrameworkPlugin') && fincorbus_options('apple_icons_114x114', 'url') ) {
			echo '<link rel="apple-touch-icon" sizes="114x114" href="' . esc_url( fincorbus_options('apple_icons_114x114', 'url') ) . '">';
		}	
	}
}


//	Theme Preloader
function fincorbus_preloader() {
	
	$fincorbus_preloader = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('preloader') : 0;
	
	if( $fincorbus_preloader != 0 ) {
		echo '<div id="loader"><div class="loader_wrap"><span>' . esc_attr__( 'Loading', 'fincorbus' ) . '</span><div class="bar_wrap"><div class="bar"></div></div></div></div>';
	}
}


//	Social Links
if ( ! function_exists( 'fincorbus_social_links' ) ) { 

	function fincorbus_social_links() {
		
		$output = '';
		$fincorbus_social_links = array();
		
		if( class_exists('ReduxFrameworkPlugin') ) {
			if( fincorbus_options('facebook_link') != '' ) {
				$fincorbus_social_links['facebook'] = fincorbus_options('facebook_link');
			}
			if( fincorbus_options('twitter_link') != '' ) {
				$fincorbus_social_links['twitter'] = fincorbus_options('twitter_link');
			}
			if( fincorbus_options('linkedin_link') != '') {
				$fincorbus_social_links['linkedin'] = fincorbus_options('linkedin_link');
			}
			if( fincorbus_options('pinterest_link') != '' ) {
				$fincorbus_social_links['pinterest'] = fincorbus_options('pinterest_link');
			}
			if( fincorbus_options('googleplus_link') != '' ) {
				$fincorbus_social_links['google-plus'] = fincorbus_options('googleplus_link');
			}
			if( fincorbus_options('flickr_link') != '' ) {
				$fincorbus_social_links['flickr'] = fincorbus_options('flickr_link');
			}
			if( fincorbus_options('instagram_link') != '' ) {
				$fincorbus_social_links['instagram'] = fincorbus_options('instagram_link');
			}
			if( fincorbus_options('behance_link') != '' ) {
				$fincorbus_social_links['behance'] = fincorbus_options('behance_link');
			}
			if( fincorbus_options('youtube_link') != '' ) {
				$fincorbus_social_links['youtube'] = fincorbus_options('youtube_link');
			}
			if( fincorbus_options('vimeo_link') != '' ) {
				$fincorbus_social_links['vimeo'] = fincorbus_options('vimeo_link');
			}
			if( fincorbus_options('rss_link') != '' ) {
				$fincorbus_social_links['rss'] = fincorbus_options('rss_link');
			}
			if( fincorbus_options('tumblr_link') != '' ) {
				$fincorbus_social_links['tumblr'] = fincorbus_options('tumblr_link');
			}
			if( fincorbus_options('reddit_link') != '' ) {
				$fincorbus_social_links['reddit'] = fincorbus_options('reddit_link');
			}
			if( fincorbus_options('dribbble_link') != '' ) {
				$fincorbus_social_links['dribbble'] = fincorbus_options('dribbble_link');
			}
			if( fincorbus_options('digg_link') != '' ) {
				$fincorbus_social_links['digg'] = fincorbus_options('digg_link');
			}
			if( fincorbus_options('skype_link') != '' ) {
				$fincorbus_social_links['skype'] = fincorbus_options('skype_link');
			}
			if( fincorbus_options('yahoo_link') != '' ) {
				$fincorbus_social_links['yahoo'] = fincorbus_options('yahoo_link');
			}
			if( fincorbus_options('vk_link') != '' ) {
				$fincorbus_social_links['vk'] = fincorbus_options('vk_link');
			}
			if( fincorbus_options('tripadvisor_link') != '' ) {
				$fincorbus_social_links['tripadvisor'] = fincorbus_options('tripadvisor_link');
			}
		}
		
		$fincorbus_icon_class = '';
		$fincorbus_social_link = '';
		
		if( isset( $fincorbus_social_links ) && is_array( $fincorbus_social_links ) ) {
			foreach( $fincorbus_social_links as $fincorbus_icon => $fincorbus_link ) {
				$fincorbus_icon_class = $fincorbus_icon;
				
				$fincorbus_social_link .= '<a class="social_link ' . esc_attr( $fincorbus_icon ) . '" href="' . esc_url( $fincorbus_link ) . '" target="_blank"><i class="fa fa-' . esc_attr( $fincorbus_icon ) . '"></i><i class="fa fa-' . esc_attr( $fincorbus_icon ) . '"></i></a>';
			}
		}
		
		if( isset( $fincorbus_social_link ) && $fincorbus_social_link != '' ) {
			$output .= $fincorbus_social_link;
		}

		return $output;
	}
}


/**
 * Post excerpt
 */
if (!function_exists('fincorbus_smarty_modifier_truncate')) {
    function fincorbus_smarty_modifier_truncate($string, $length = 80, $etc = '... ',
		$break_words = false)
    {
        if ($length == 0)
            return '';

        if (mb_strlen($string, 'utf8') > $length) {
            $length -= mb_strlen($etc, 'utf8');
            if (!$break_words) {
                $string = preg_replace('/\s+\S+\s*$/su', '', mb_substr($string, 0, $length + 1, 'utf8'));
            }
            return mb_substr($string, 0, $length, 'utf8') . $etc;
        } else {
            return $string;
        }
    }
}


//	Comments Count
if (!function_exists('fincorbus_comment_count')) {
	function fincorbus_comment_count() {
		$fincorbus_comment_count = get_comments_number('0', '1', '%');
		if ($fincorbus_comment_count == 0) {
			$fincorbus_comment_trans = esc_attr__('No Comments', 'fincorbus');
		} elseif ($fincorbus_comment_count == 1) {
			$fincorbus_comment_trans = esc_attr__('1 Comment', 'fincorbus');
		} else {
			$fincorbus_comment_trans = $fincorbus_comment_count . ' ' . esc_attr__('Comments', 'fincorbus');
		}
		return '<a class="cstheme_comment_count" href="' . get_comments_link() . '" title="' . $fincorbus_comment_trans . '"><i class="icon Evatheme-Icon-Fonts-thin-0274_chat_message_comment_bubble"></i>' . $fincorbus_comment_trans . '</a>';
	}
}

/**
 * Single Post Comments List
 */

if (!function_exists('fincorbus_comment')) {
    function fincorbus_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment; ?>
	
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
			<div id="comment-<?php comment_ID(); ?>" class="comment-body clearfix">
				<div class="comment-avatar">
					<?php echo get_avatar($comment, $size = '70'); ?>
				</div>
				<div class="comment-content">
					<div class="comment-meta clearfix">
						<span class="comment_author"><?php comment_author(); ?></span>
						<span class="comment-date"><?php comment_date('F jS Y. g:i a'); ?></span>
						<?php comment_reply_link(array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => '<i class="fa fa-reply"></i>' . esc_attr__('Reply', 'fincorbus') ))); ?>
						<?php edit_comment_link( esc_html__( 'Edit', 'fincorbus'),' ','' ); ?>
					</div>
					<div class="comment-text clearfix">
						<?php comment_text(); ?>
						<?php if ( $comment->comment_approved == '0' ) : ?>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'fincorbus'); ?></em>
							<br>
						<?php endif; ?>
					</div>
				</div>
			</div>
	<?php
	}
}


//	Display navigation to next/previous set of posts when applicable.
if ( ! function_exists( 'fincorbus_pagination' ) ) { 

	function fincorbus_pagination( $pages = '' ) {
		
		global $wp_query, $wp_rewrite;
		
		$compile = '';
		
		$pages = ($pages) ? $pages : $wp_query->max_num_pages;

		// Don't print empty markup if there's only one page.
		if ( $pages < 2 ) {
			return;
		}

		$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		$pagenum_link = html_entity_decode( get_pagenum_link() );
		$query_args   = array();
		$url_parts    = explode( '?', $pagenum_link );
	
		if ( isset( $url_parts[1] ) ) {
			wp_parse_str( $url_parts[1], $query_args );
		}
	
		$pagenum_link = esc_url ( remove_query_arg( array_keys( $query_args ), $pagenum_link ) );
		$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';
	
		$format  = $wp_rewrite->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
		$format .= $wp_rewrite->using_permalinks() ? user_trailingslashit( $wp_rewrite->pagination_base . '/%#%', 'paged' ) : '?paged=%#%';
		
		// Set up paginated links.
		$links = paginate_links( array(
			'base'     				=> $pagenum_link,
			'format'   				=> $format,
			'total'    				=> $pages,
			'current'  				=> $paged,
			'show_all' 				=> false,
			'mid_size' 				=> 2,
			'type' 					=> 'array',
			'add_args' 				=> array_map( 'urlencode', $query_args ),
			'prev_text' 			=> esc_html__('Previous', 'fincorbus'),
			'next_text' 			=> esc_html__('Next', 'fincorbus'),
		) );

		if ( !empty($links) ) {
			$compile .= '<div class="eva-pagination">';
			foreach( $links as $link ) {
				$compile .= $link;
			}
			$compile .= '</div>';
		}

		return $compile;
	}
}


/**
 *	Load More button
 */

if (!function_exists('fincorbus_infinite_scroll')) {
	function fincorbus_infinite_scroll( $pages = "" ) {
		
		global $paged, $fincorbus_wp_query_in_shortcodes;
		
		$compile = '';

        if (empty($paged)) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        }
		$pages = intval($fincorbus_wp_query_in_shortcodes->max_num_pages);
		if (empty($pages)) {
			$pages = 1;
		}
		if (1 != $pages) {
			$compile .= '<div class="text-center">';
				$compile .= '<div class="eva-infinite-scroll" data-has-next="' . ( $paged === $pages ? 'false' : 'true' ) . '">';
					$compile .= '<a class="btn btn-infinite-scroll no-more hide" href="#">' . esc_html__('No more posts', 'fincorbus') . '</a>';
					$compile .= '<a class="btn btn-infinite-scroll loading" href="#"><i class="fa fa-refresh"></i></a>';
					$compile .= '<a class="btn btn-infinite-scroll next" href="' . get_pagenum_link( $paged + 1 ) . '">' . esc_html__('Load more posts', 'fincorbus') . '</a>';
				$compile .= '</div>';
			$compile .= '</div>';
		}
		
		return $compile; 
	}
}



//	Post Likes
function fincorbus_enqueue_script() {
	wp_enqueue_script('fincorbus_ajaxurl', get_template_directory_uri() . '/assets/js/jquery.cookie.js', array('jquery'), false, true);
	wp_add_inline_script( 'fincorbus_ajaxurl', 'var fincorbus_ajaxurl = "' . admin_url("admin-ajax.php") . '";' );
}
add_action( 'wp_enqueue_scripts', 'fincorbus_enqueue_script' );

function fincorbus_likes() {
	
	wp_enqueue_script('fincorbus_cookie', get_template_directory_uri() . '/assets/js/jquery.cookie.js', array('jquery'), false, true);
    $fincorbus_all_likes = get_post_meta(get_the_ID(), 'fincorbus_likes', true);
    if (!isset($fincorbus_all_likes) || absint($fincorbus_all_likes) < 1) {
        $fincorbus_all_likes = 0;
    }
    
	if( class_exists( 'ReduxFrameworkPlugin' ) ) {
		echo '
		<span class="cstheme_likes ' . (isset($_COOKIE['like' . get_the_ID()]) ? "already_liked" : "fincorbus_add_like") . '" data-postid="' . get_the_ID() . '">
			<i class="fa fa-heart-o"></i>
			<span class="likes_count">' . esc_html( $fincorbus_all_likes ) . '</span>
		</span>
		';
	}
}

add_action('wp_ajax_add_like_post', 'fincorbus_add_like_post');
add_action('wp_ajax_nopriv_add_like_post', 'fincorbus_add_like_post');
function fincorbus_add_like_post() {
    $fincorbus_post_id = absint($_POST['post_id']);
    $fincorbus_all_likes = get_post_meta($fincorbus_post_id, 'fincorbus_likes', true);
    $fincorbus_all_likes = (isset($fincorbus_all_likes) ? $fincorbus_all_likes : 0) + 1;
    update_post_meta($fincorbus_post_id, 'fincorbus_likes', $fincorbus_all_likes);
    echo esc_html( $fincorbus_all_likes );
    die();
}



//	Posts per author posts page
add_filter( 'pre_option_posts_per_page', 'fincorbus_author_posts_per_page' );
function fincorbus_author_posts_per_page( $posts_per_page ) {
	global $wp_query;
	if ( is_author() ) {
		return 9;
	}
	
	if ( is_search() ) {
		return 500;
	} 

	return $posts_per_page;
}


//	Portfolio Filter
if (!function_exists('fincorbus_portfolio_filter')) {
    function fincorbus_portfolio_filter($post_type_terms = "")
    {
        if (!isset($term_list)) {
            $term_list = '';
        }
        $permalink = get_permalink();
        $args = array('taxonomy' => 'Category', 'include' => $post_type_terms);
        $terms = get_terms('portfolio_category', $args);
        $count = count($terms);
        $i = 0;
        $iterm = 1;
		
		$compile = '';
		
        if ($count > 0) {
            $cape_list = '';
            if ($count > 1) {
                $term_list .= '<li class="' . (!isset($_GET['slug']) ? 'selected' : '') . '">';

                $args_for_count_all_terms = array(
                    'post_type' => 'portfolio',
                    'post_status' => 'publish'
                );
                $query_for_count_all_terms = new WP_Query($args_for_count_all_terms);

                $term_list .= '<a href="#filter" data-option-value="*" data-catname="all" data-title="' . $query_for_count_all_terms->post_count . '">' . esc_html__('All', 'fincorbus') . '</a>
				</li>';
            }
            $termcount = count($terms);
            if (is_array($terms)) {
                foreach ($terms as $term) {

                    $args_for_count_all_terms = array(
                        'post_type' => 'portfolio',
                        'post_status' => 'publish',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'portfolio_category',
                                'field' => 'id',
                                'terms' => $term->term_id
                            )
                        )
                    );
                    $query_for_count_all_terms = new WP_Query($args_for_count_all_terms);

                    $i++;
                    $permalink = esc_url(add_query_arg("slug", $term->term_id, $permalink));
                    $term_list .= '<li ';
                    if (isset($_GET['slug'])) {
                        $getslug = $_GET['slug'];
                    } else {
                        $getslug = '';
                    }

                    if (strnatcasecmp($getslug, $term->term_id) == 0) $term_list .= 'class="selected"';

                    $tempname = strtr($term->name, array(
                        ' ' => '-',
                    ));
                    $tempname = strtolower($tempname);
                    $term_list .= '><a data-option-value=".' . $tempname . '" data-catname="' . $tempname . '" href="#filter"  data-title="' . $query_for_count_all_terms->post_count . '">' . $term->name . '</a>
                </li>';
                    if ($count != $i) $term_list .= ' '; else $term_list .= '';

                    $iterm++;
                }
            }
            
			$compile .= '<div class="filter_block"><ul data-option-key="filter" class="optionset">' . $term_list . '</ul></div>';
			
			return $compile;
			
        }
    }
}


/**
 * Generate dynamic css
 */

if ( !function_exists( 'fincorbus_generate_dynamic_css' ) ):
	function fincorbus_generate_dynamic_css() {
		ob_start();
		get_template_part( 'assets/css/dynamic-css' );
		$output = ob_get_contents();
		ob_end_clean();
		return fincorbus_compress_css_code( $output );
	}
endif;


/**
 * Compress CSS Code
 */

if ( !function_exists( 'fincorbus_compress_css_code' ) ) :
	function fincorbus_compress_css_code( $code ) {

		// Remove Comments
		$code = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $code );

		// Remove tabs, spaces, newlines, etc.
		$code = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), '', $code );

		return $code;
	}
endif;