<?php 

if ( !function_exists( 'woocommerce_support' ) ) {
	function woocommerce_support() {
		add_theme_support( 'woocommerce' );
	}
}
add_action( 'after_setup_theme', 'woocommerce_support' );


/**
 * Hooks to WooCommerce actions, filters
 */

add_filter( 'fincorbus_after_single_product_image', 'fincorbus_product_thumbnails' );


//	Products Columns
add_filter('loop_shop_columns', 'fincorbus_shop_columns');
if (!function_exists('fincorbus_shop_columns')) {
	function fincorbus_shop_columns() {
		
		if( class_exists( 'ReduxFrameworkPlugin' ) ) {
			if( fincorbus_options('shop_columns') == 'col2' ) {
				return 2;
			} else if( fincorbus_options('shop_columns') == 'col3' ){
				return 3;
			} else {
				return 4;
			}
		} else {
			return 3;
		}
	}
}


//	Product image size
if (!function_exists('fincorbus_woocommerce_image_dimensions')) {
	function fincorbus_woocommerce_image_dimensions() {
		$catalog = array(
			'width' 	=> '370',
			'height'	=> '370',
			'crop'		=> 1
		);
		
		$single = array(
			'width' 	=> '570',
			'height'	=> '570',
			'crop'		=> 1
		);

		$thumbnail = array(
			'width' 	=> '70',
			'height'	=> '70',
			'crop'		=> 1
		);

		// Image sizes
		update_option( 'shop_catalog_image_size', $catalog );
		update_option( 'shop_single_image_size', $single );
		update_option( 'shop_thumbnail_image_size', $thumbnail );
	}
}
add_action( 'init', 'fincorbus_woocommerce_image_dimensions' );


//	Products per page
add_filter( 'loop_shop_per_page', function ( $cols ) {

	$fincorbus_products_per_page = ( strlen( fincorbus_options('products_per_page') ) > 0 ) ? intval( fincorbus_options('products_per_page') ) : 6;
	
	return $fincorbus_products_per_page;
}, 20 );


//	Page Title
add_filter('woocommerce_show_page_title', 'fincorbus_woo_title_none');
if (!function_exists('fincorbus_woo_title_none')) {
	function fincorbus_woo_title_none(){
		return false;
	}
}

//	WooCommerce Product Item
add_action('woocommerce_before_shop_loop_item', 'fincorbus_before_shop_loop_item',5);
add_action('woocommerce_after_shop_loop_item', 'fincorbus_after_shop_loop_item',5);

if ( ! function_exists( 'fincorbus_before_shop_loop_item' ) ) {
	function fincorbus_before_shop_loop_item() {
		global $woocommerce, $product, $post;
		
		$fincorbus_products_list_type = class_exists( 'ReduxFrameworkPlugin' ) ? fincorbus_options('products_list_type') : 'type1';
		
		?>
		
		<div class="product_wrap <?php if ( $product->is_on_sale() ) { echo 'product_sale'; } ?> <?php echo 'products_list_' . $fincorbus_products_list_type; ?>">

			<?php if( $fincorbus_products_list_type == 'type2' ) { ?>
				
				<div class="shop_list_product_image">
					<a href="<?php the_permalink(); ?>">
						<?php 
							echo woocommerce_get_product_thumbnail();
							
							$attachment_ids = $product->get_gallery_image_ids();
							if ( $attachment_ids ) {
								$secondary_image_id = $attachment_ids['0'];
								echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
							}
						?>
					</a>
					<?php if ( $product->is_on_sale() ) {

						$fincorbus_sale_text = esc_attr__( 'Sale', 'fincorbus' );
				
						echo apply_filters( 'woocommerce_sale_flash', '<span class="onsale">' . $fincorbus_sale_text . '</span>', $post, $product );
						
					} ?>
				</div>
				<div class="shop_list_product_descr">
					<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="product_categories">', '</span>' ); ?>
					<h6 class="product-title"><a href="<?php the_permalink()?>"><?php the_title(); ?></a></h6>
					<div class="price_wrap"><?php woocommerce_template_loop_price(); ?></div>
				</div>
			
			<?php } elseif( $fincorbus_products_list_type == 'type3' ) { ?>
				
				<div class="shop_list_product_image">
					<a href="<?php the_permalink(); ?>">
						<?php 
							echo woocommerce_get_product_thumbnail();
							
							$attachment_ids = $product->get_gallery_image_ids();
							if ( $attachment_ids ) {
								$secondary_image_id = $attachment_ids['0'];
								echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
							}
						?>
					</a>
					<?php if ( $product->is_on_sale() ) {

						$fincorbus_sale_text = esc_attr__( 'Sale', 'fincorbus' );
				
						echo apply_filters( 'woocommerce_sale_flash', '<span class="onsale">' . $fincorbus_sale_text . '</span>', $post, $product );
						
					} ?>
					<?php woocommerce_template_loop_add_to_cart(); ?>
				</div>
				<div class="shop_list_product_descr">
					<div class="clearfix">
						<h6 class="product-title"><a href="<?php the_permalink()?>"><?php the_title(); ?></a></h6>
						<?php woocommerce_template_loop_price(); ?>
					</div>
					<?php woocommerce_template_loop_rating(); ?>
				</div>
			
			<?php } elseif( $fincorbus_products_list_type == 'type4' ) { ?>
				
				<div class="shop_list_product_image">
					<a href="<?php the_permalink(); ?>">
						<?php 
							echo woocommerce_get_product_thumbnail();
							
							$attachment_ids = $product->get_gallery_image_ids();
							if ( $attachment_ids ) {
								$secondary_image_id = $attachment_ids['0'];
								echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
							}
						?>
					</a>
					<?php if ( $product->is_on_sale() ) {

						$fincorbus_sale_text = esc_attr__( 'Sale', 'fincorbus' );
				
						echo apply_filters( 'woocommerce_sale_flash', '<span class="onsale">' . $fincorbus_sale_text . '</span>', $post, $product );
						
					} ?>
					<?php woocommerce_template_loop_add_to_cart(); ?>
				</div>
				<div class="shop_list_product_descr text-center">
					<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="product_categories">', '</span>' ); ?>
					<h6 class="product-title"><a href="<?php the_permalink()?>"><?php the_title(); ?></a></h6>
					<?php woocommerce_template_loop_price(); ?>
				</div>
				
			<?php } elseif( $fincorbus_products_list_type == 'type5' ) { ?>
				
				<div class="shop_list_product_image">
					<a href="<?php the_permalink(); ?>">
						<?php 
							echo woocommerce_get_product_thumbnail();
							
							$attachment_ids = $product->get_gallery_image_ids();
							if ( $attachment_ids ) {
								$secondary_image_id = $attachment_ids['0'];
								echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
							}
						?>
					</a>
					<?php if ( $product->is_on_sale() ) {

						$fincorbus_sale_text = esc_attr__( 'Sale', 'fincorbus' );
				
						echo apply_filters( 'woocommerce_sale_flash', '<span class="onsale">' . $fincorbus_sale_text . '</span>', $post, $product );
						
					} ?>
				</div>
				<div class="shop_list_product_descr">
					<h6 class="product-title"><a href="<?php the_permalink()?>"><?php the_title(); ?></a></h6>
					<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="product_categories">', '</span>' ); ?>
					<?php woocommerce_template_loop_price(); ?>
				</div>
				
			<?php } else { ?>
				
				<div class="shop_list_product_image">
					<a href="<?php the_permalink(); ?>">
						<?php 
							echo woocommerce_get_product_thumbnail();
							
							$attachment_ids = $product->get_gallery_image_ids();
							if ( $attachment_ids ) {
								$secondary_image_id = $attachment_ids['0'];
								echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
							}
						?>
					</a>
					<?php if ( $product->is_on_sale() ) {

						$fincorbus_sale_text = esc_attr__( 'Sale', 'fincorbus' );
				
						echo apply_filters( 'woocommerce_sale_flash', '<span class="onsale">' . $fincorbus_sale_text . '</span>', $post, $product );
						
					} ?>
				</div>
				<div class="shop_list_product_descr">
					<h6 class="product-title"><a href="<?php the_permalink()?>"><?php the_title(); ?></a></h6>
					
					<?php woocommerce_template_loop_rating(); ?>
					
					<div class="clearfix">
						<span class="price"><?php woocommerce_template_loop_price(); ?></span>
						
						<?php woocommerce_template_loop_add_to_cart(); ?>
					</div>
				</div>
				
			<?php } ?>

			<div class="hide">
			<?php
	}
}

if ( ! function_exists( 'fincorbus_after_shop_loop_item' ) ) {
	function fincorbus_after_shop_loop_item() {
		?>
			</div>
		</div>
		<?php
	}
}


// Custom Shop Pagination
remove_action('woocommerce_after_shop_loop', 'woocommerce_pagination', 10);
add_action('woocommerce_after_shop_loop', 'fincorbus_get_shop_pagination', 10);
if (!function_exists('fincorbus_get_shop_pagination')) {	
	function fincorbus_get_shop_pagination() {
		echo fincorbus_pagination();
	}
}


/* Change Positions */
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_title',5);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price',10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt',20);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart',30);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta',40);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing',50);

add_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 10);
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 20);
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 30);
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 40);	
add_action('woocommerce_single_product_summary', 'fincorbus_woocommerce_template_single_meta', 50);
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 60);


/* Product Single Share Buttons */
add_action('woocommerce_share','fincorbus_wooshare');
function fincorbus_wooshare(){
	
	global $post;

	$fincorbus_featured_image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), false, '' );
?>
	
	<?php if( class_exists( 'ReduxFrameworkPlugin' ) ) { ?>
		<div class="cswoo_sharebox">
			<b><?php echo esc_attr__( 'Share', 'fincorbus' ); ?></b>
			<div class="cswoo_sharebox_links">
				<a class="cswoo_social_link facebook" href="http://www.facebook.com/sharer.php?u=<?php the_permalink();?>&t=<?php the_title(); ?>" title="<?php echo esc_attr__( 'Facebook', 'fincorbus') ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-facebook"></i></a>
				
				<a class="cswoo_social_link twitter" href="http://twitter.com/home?status=<?php the_title(); ?> <?php the_permalink(); ?>" title="<?php echo esc_attr__( 'Twitter', 'fincorbus') ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-twitter"></i></a>
				
				<a class="cswoo_social_link google-plus" href="http://plus.google.com/share?url=<?php the_permalink() ?>&amp;title=<?php echo str_replace(' ', '+', the_title('', '', false)); ?>" title="<?php echo esc_attr__( 'Google+', 'fincorbus') ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-google-plus"></i></a>
				
				<a class="cswoo_social_link pinterest" href="http://pinterest.com/pin/create/button/?url=<?php echo get_permalink(); ?>&media=<?php echo (strlen($fincorbus_featured_image_url[0]) > 0) ? $fincorbus_featured_image_url[0] : get_option( 'fincorbus_logo' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-pinterest-p"></i></a>
			</div>
		</div>
	<?php } ?>
	
<?php
}


/* Related Products on Single page */
add_filter( 'woocommerce_output_related_products_args', 'fincorbus_related_products_args' );
function fincorbus_related_products_args( $args ) {
	
	$args['posts_per_page'] = 4;
	
	return $args;
}


//	Single Meta
function fincorbus_woocommerce_template_single_meta(){
	global $post, $product;
	
	?>
	<div class="product_meta">

		<?php do_action( 'woocommerce_product_meta_start' ); ?>

		<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

			<span class="sku_wrapper"><b><?php echo esc_attr__( 'SKU', 'fincorbus' ); ?></b><span class="sku" itemprop="sku"><?php echo esc_html( $sku = $product->get_sku() ) ? esc_html( $sku ) : esc_attr__( 'N/A', 'fincorbus' ); ?></span></span>

		<?php endif; ?>

		<?php if( count( $product->get_category_ids() ) > 0 ){ ?>
			<span class="posted_in"><b><?php echo esc_attr__( 'Categories', 'fincorbus' ); ?></b><?php echo wc_get_product_category_list( $product->get_id(), ', ' ); ?></span>
		<?php } ?>
		
		<?php if( count( $product->get_tag_ids() ) > 0 ){ ?>
			<span class="tagged_as"><b><?php echo esc_attr__( 'Tags', 'fincorbus' ); ?></b><?php echo wc_get_product_tag_list( $product->get_id(), ', ' ); ?></span>
		<?php } ?>

		<?php do_action( 'woocommerce_product_meta_end' ); ?>

	</div>
<?php }


//	Nav Cart Icon
if(!function_exists('fincorbus_woo_nav_cart')) {
	function fincorbus_woo_nav_cart() {
		global $woocommerce;
	
		$inactive = '';
		$cart_count = $woocommerce->cart->get_cart_contents_count();
		?>
	
		<div id="woo-nav-cart">
			<div class="nav-cart-content">
				<i class="icon Evatheme-Icon-Fonts-thin-0443_shopping_cart_basket_store"></i>
				<?php if( $cart_count > 0 ) { ?>
					<span class="woo-cart-count"><?php echo esc_attr( $cart_count ); ?></span>
				<?php } ?>
			</div>
			<div class="nav-cart-products <?php if( $cart_count < 1 ) { echo 'cart_empty';} ?>">
				<div class="widget_shopping_cart"><div class="widget_shopping_cart_content"></div></div>				
			</div>
		</div>
	
	<?php 
	}
}


/**
 * Get product thumnails
 *
 * @since  1.0.0
 * @return string
 */
function fincorbus_product_thumbnails() {
	global $post, $product, $woocommerce;

	$attachment_ids = $product->get_gallery_image_ids();

	if ( $attachment_ids ) {
		
		?>
		<div class="product-thumbnails" id="product-thumbnails">
			<div class="thumbnails"><?php

				$image_thumb = get_the_post_thumbnail( $post->ID, apply_filters( 'single_product_small_thumbnail_size', 'shop_thumbnail' ) );

				if ( $image_thumb ) {

					printf(
						'<div>%s</div>',
						$image_thumb
					);

				}

				if ( $attachment_ids ) {
					foreach ( $attachment_ids as $attachment_id ) {

						$props = wc_get_product_attachment_props( $attachment_id, $post );

						if ( ! $props['url'] ) {
							continue;
						}

						echo apply_filters(
							'woocommerce_single_product_image_thumbnail_html',
							sprintf(
								'<div>%s</div>',
								wp_get_attachment_image( $attachment_id, apply_filters( 'single_product_small_thumbnail_size', 'shop_thumbnail' ), 0, $props )
							),
							$attachment_id,
							$post->ID
						);
					}
				}

				?>
			</div>
		</div>
		<?php
	}

}


// Breadcrumbs
add_filter( 'woocommerce_breadcrumb_defaults', 'fincorbus_change_breadcrumb_delimiter' );
function fincorbus_change_breadcrumb_delimiter( $defaults ) {
	$defaults['delimiter'] = '<span class="sep"><i class="fa fa-chevron-right"></i></span>';
	return $defaults;
}